import React, { useState, useEffect } from 'react'
import axios from 'axios'
import { toast } from 'react-toastify';
import { useLocation } from 'react-router-dom'
import { useSelector, useDispatch } from 'react-redux';
import {clearSceneHandler} from '@store/actions/saved-scene-actions'
import { useLoader } from '@services/LoaderContext';

import getHeaders from '@services/headersService';
import Loader from '@shared/loader/loader';
import { getEndpointBaseURL } from '@services/environment'
import { setSavedProject, clearSavedProjectData } from '@store/actions/saved-project-actions';

// import VisualizationContainer from './visualization-container/visualization-container'
// import VisualizationOptions from './visualization-options/visualization-options'

import './visualizer-info.scss'

const VisualizerInfo = () => {
  const dispatch = useDispatch();
  const dispatchSceneHandler = useDispatch();
  const clearDispatch = useDispatch();
  const { showLoader, hideLoader, isLoading, loaderConfig } = useLoader();
  const [isStartOver, setIsStartOver] = useState(false)
  const params = useLocation().search;
  const name = new URLSearchParams(params).get('fetchPin');
  const savedSceneDetails = useSelector((state) => state.savedScene);

  useEffect(() => {
    if(name !== '' && name !== null) {
      showLoader(); // Show loader
      const item = axios.get(getEndpointBaseURL() + 'retrieveScene/' + name, { headers: getHeaders() });
      item.then(res => {
        const sessionData = res.data.data[0]?.session_data;
        if(sessionData){
          startOver(sessionData)
        }else{
          toast.error(res.data.message, {
            position: "top-right",
            hideProgressBar: false,
            theme: "colored"
          });
        }
        hideLoader();
      })
      .catch(error => {
        hideLoader();
        toast.error(error, {
          position: "top-right",
          hideProgressBar: false,
          theme: "colored"
        });
      })
    }
  }, [])

  const startOver = details => {
    savedSceneDetails?.currentScene?.deleteAllBlindDetails();
    clearDispatch(clearSavedProjectData());
    dispatchSceneHandler(clearSceneHandler());
    dispatch(setSavedProject(details));
    setIsStartOver(true)
  }

  const startOverHandler = (isValid) => {
    if(isValid === false){
      setIsStartOver(!!isStartOver)
    }else{
      setIsStartOver(!isStartOver)
    }
  }

  return (
    <>
      <div className='visualizer-info-container'>
        {isLoading && <Loader {...loaderConfig}/>}
        {!isStartOver ? (
          'VisualizationOptions'
          // <VisualizationOptions onSelect={details => startOver(details)} />
        ) : (
          'VisualizationContainer'
          // <VisualizationContainer
          //   startOver={startOverHandler}
          //   retrieveSession={details => {startOver(details); setIsStartOver(true)}}
          // />
        )}
      </div>
    </>
  )
}

export default VisualizerInfo

